@@ -1,4 +1,4 @@
-# $Id: Checkout.pm 847 2005-09-21 00:34:05Z claco $
+# $Id: Checkout.pm 853 2005-09-21 01:14:42Z claco $
 package Catalyst::Helper::Controller::Handel::Checkout;
 use strict;
 use warnings;
@@ -21,11 +21,11 @@ sub mk_compclass {
     $helper->{'omodel'} = $helper->{'app'} . '::M::' . $omodel;
 
     my $curi = $ccontroller =~ /^(.*::C(ontroller)?::)?(.*)$/i ? lc($3) : 'cart';
-    $curi =~ s/::/\//;
+    $curi =~ s/::/\//g;
     $helper->{'curi'} = $curi;
 
     my $ouri = $ocontroller =~ /^(.*::C(ontroller)?::)?(.*)$/i ? lc($3) : 'orders';
-    $ouri =~ s/::/\//;
+    $ouri =~ s/::/\//g;
     $helper->{'ouri'} = $ouri;
 
     $helper->mk_dir($dir);
