@@ -1,4 +1,4 @@
-# $Id: Constraints.pm 547 2005-06-25 02:09:43Z claco $
+# $Id: Constraints.pm 792 2005-09-12 02:04:00Z claco $
 package Handel::Constraints;
 use strict;
 use warnings;
@@ -6,7 +6,7 @@ use vars qw(@EXPORT_OK %EXPORT_TAGS);
 
 BEGIN {
     use base 'Exporter';
-    use Handel::ConfigReader;
+    use Handel;
     use Handel::Constants qw(:cart :checkout :order);
     use Handel::Exception;
     use Handel::L10N qw(translate);
@@ -29,7 +29,7 @@ sub constraint_quantity {
     my $value = defined $_[0] ? shift : '';
     my ($object, $column, $changing) = @_;
 
-    my $cfg    = Handel::ConfigReader->new();
+    my $cfg    = $Handel::Cfg;
     my $max    = $cfg->{'HandelMaxQuantity'};
     my $action = $cfg->{'HandelMaxQuantityAction'};
 
@@ -96,7 +96,8 @@ sub constraint_checkout_phase {
     return if $value !~ /[0-9]/;
 
     if ($value != CHECKOUT_PHASE_INITIALIZE && $value != CHECKOUT_PHASE_VALIDATE &&
-        $value != CHECKOUT_PHASE_AUTHORIZE && $value != CHECKOUT_PHASE_DELIVER) {
+        $value != CHECKOUT_PHASE_FINALIZE && $value != CHECKOUT_PHASE_AUTHORIZE &&
+        $value != CHECKOUT_PHASE_DELIVER) {
         return 0;
     };
     return 1;
